@@ -169,6 +169,7 @@ static SCM scm_set_feature_word(SCM features)
   enabled_features = SCM_INUM(features);
 
   droppable_is_featured = (enabled_features & DROPPABLE_FMASK);
+  score_is_hidden = (enabled_features & SCOREHIDDEN_FMASK);
 
   return SCM_EOL;
 }
@@ -284,7 +285,12 @@ static SCM scm_myrandom(SCM range)
   return scm_long2num(g_random_int_range(0,SCM_INUM(range)));
 }
 
-static SCM scm_get_score() 
+static SCM scm_click_to_move_p (void)
+{
+  return click_to_move ? SCM_BOOL_T : SCM_BOOL_F;
+}
+
+static SCM scm_get_score(void) 
 {
   return scm_long2num(score);
 }
@@ -328,6 +334,7 @@ void cscm_init ()
   scm_c_define_gsubr("set-slot-x-expansion!", 2, 0, 0, scm_set_slot_x_expansion);
   scm_c_define_gsubr("set-lambda", 8, 0, 1, scm_set_lambda);
   scm_c_define_gsubr("random", 1, 0, 0, scm_myrandom);
+  scm_c_define_gsubr("click-to-move?", 0, 0, 0, scm_click_to_move_p);
   scm_c_define_gsubr("get-score", 0, 0, 0, scm_get_score);  
   scm_c_define_gsubr("set-score!", 1, 0, 0, scm_set_score);
   scm_c_define_gsubr("get-timeout", 0, 0, 0, scm_get_timeout);  
@@ -515,6 +522,7 @@ SCM
 cscmi_start_game_lambda (void)
 {
   CallData *call_data;
+  SCM retval;
 
   call_data = g_new0 (CallData, 1);
   call_data->lambda = game_data->start_game_lambda;
@@ -524,9 +532,10 @@ cscmi_start_game_lambda (void)
 		      call_data,
 		      cscmi_catch_handler,
 		      NULL);
+  retval = call_data->retval;
   g_free (call_data);
 
-  return call_data->retval;
+  return retval;
 }
 
 SCM
@@ -534,6 +543,7 @@ cscmi_button_pressed_lambda (SCM slot_id,
 			     SCM cards)
 {
   CallData *call_data;
+  SCM retval;
 
   call_data = g_new0 (CallData, 1);
   call_data->lambda = game_data->button_pressed_lambda;
@@ -545,9 +555,10 @@ cscmi_button_pressed_lambda (SCM slot_id,
 		      call_data,
 		      cscmi_catch_handler,
 		      NULL);
+  retval = call_data->retval;
   g_free (call_data);
 
-  return call_data->retval;
+  return retval;
 }
 
 SCM
@@ -556,6 +567,7 @@ cscmi_button_released_lambda (SCM start_slot,
 			      SCM end_slot)
 {
   CallData *call_data;
+  SCM retval;
 
   call_data = g_new0 (CallData, 1);
   call_data->lambda = game_data->button_released_lambda;
@@ -568,15 +580,17 @@ cscmi_button_released_lambda (SCM start_slot,
 		      call_data,
 		      cscmi_catch_handler,
 		      NULL);
+  retval = call_data->retval;
   g_free (call_data);
 
-  return call_data->retval;
+  return retval;
 }
 
 SCM
 cscmi_button_clicked_lambda (SCM slot_id)
 {
   CallData *call_data;
+  SCM retval;
 
   call_data = g_new0 (CallData, 1);
   call_data->lambda = game_data->button_clicked_lambda;
@@ -587,15 +601,17 @@ cscmi_button_clicked_lambda (SCM slot_id)
 		      call_data,
 		      cscmi_catch_handler,
 		      NULL);
+  retval = call_data->retval;
   g_free (call_data);
 
-  return call_data->retval;
+  return retval;
 }
 
 SCM
 cscmi_button_double_clicked_lambda (SCM slot_id)
 {
   CallData *call_data;
+  SCM retval;
 
   call_data = g_new0 (CallData, 1);
   call_data->lambda = game_data->button_double_clicked_lambda;
@@ -606,9 +622,10 @@ cscmi_button_double_clicked_lambda (SCM slot_id)
 		      call_data,
 		      cscmi_catch_handler,
 		      NULL);
+  retval = call_data->retval;
   g_free (call_data);
 
-  return call_data->retval;
+  return retval;
 }
 
 SCM
@@ -617,6 +634,7 @@ cscmi_droppable_lambda (SCM start_slot,
                         SCM end_slot)
 {
   CallData *call_data;
+  SCM retval;
 
   if (!droppable_is_featured) 
     return SCM_BOOL_F;
@@ -632,15 +650,17 @@ cscmi_droppable_lambda (SCM start_slot,
                       call_data,
                       cscmi_catch_handler,
                       NULL);
+  retval = call_data->retval;
   g_free (call_data);
 
-  return call_data->retval;
+  return retval;
 }
 
 SCM
 cscmi_game_over_lambda (void)
 {
   CallData *call_data;
+  SCM retval;
 
   call_data = g_new0 (CallData, 1);
   call_data->lambda = game_data->game_over_lambda;
@@ -650,15 +670,17 @@ cscmi_game_over_lambda (void)
 		      call_data,
 		      cscmi_catch_handler,
 		      NULL);
+  retval = call_data->retval;
   g_free (call_data);
 
-  return call_data->retval;
+  return retval;
 }
 
 SCM
 cscmi_winning_game_lambda (void)
 {
   CallData *call_data;
+  SCM retval;
 
   call_data = g_new0 (CallData, 1);
   call_data->lambda = game_data->winning_game_lambda;
@@ -668,15 +690,17 @@ cscmi_winning_game_lambda (void)
 		      call_data,
 		      cscmi_catch_handler,
 		      NULL);
+  retval = call_data->retval;
   g_free (call_data);
 
-  return call_data->retval;
+  return retval;
 }
 
 SCM
 cscmi_hint_lambda (void)
 {
   CallData *call_data;
+  SCM retval;
 
   call_data = g_new0 (CallData, 1);
   call_data->lambda = game_data->hint_lambda;
@@ -686,9 +710,10 @@ cscmi_hint_lambda (void)
 		      call_data,
 		      cscmi_catch_handler,
 		      NULL);
+  retval = call_data->retval;
   g_free (call_data);
 
-  return call_data->retval;
+  return retval;
 }
 
 SCM
@@ -724,6 +749,7 @@ SCM
 cscmi_apply_options_lambda (SCM options)
 {
   CallData *call_data;
+  SCM retval;
 
   call_data = g_new0 (CallData, 1);
   call_data->lambda = game_data->apply_options_lambda;
@@ -734,15 +760,17 @@ cscmi_apply_options_lambda (SCM options)
 		      call_data,
 		      cscmi_catch_handler,
 		      NULL);
+  retval = call_data->retval;
   g_free (call_data);
 
-  return call_data->retval;
+  return retval;
 }
 
-SCM
+gboolean
 cscmi_timeout_lambda (void)
 {
   CallData *call_data;
+  SCM retval;
 
   call_data = g_new0 (CallData, 1);
   call_data->lambda = game_data->timeout_lambda;
@@ -752,7 +780,8 @@ cscmi_timeout_lambda (void)
 		      call_data,
 		      cscmi_catch_handler,
 		      NULL);
+  retval = call_data->retval;
   g_free (call_data);
 
-  return call_data->retval;
+  return SCM_NFALSEP (retval);
 }
