@@ -22,12 +22,24 @@
  */
 
 #include "tetris.h"
-#include "scoreframe.h"
+
+enum SlotType 
+{
+	EMPTY, 
+	FALLING, 
+	LAYING
+};
+
+struct Block
+{
+	SlotType what;
+	int color;
+};
 
 class BlockOps
 {
 public:
-	BlockOps(Field *f);
+	BlockOps();
 	~BlockOps();
 	
 	bool moveBlockLeft();
@@ -36,21 +48,26 @@ public:
 	bool rotateBlock(bool);
 	int dropBlock();
 	void fallingToLaying();
-	void checkFullLines(ScoreFrame *s);
+	int checkFullLines();
 	bool generateFallingBlock();
 	void emptyField(void);
 	void emptyField(int filled_lines, int fill_prob);
 	void putBlockInField(bool erase);
 	int getLinesToBottom();
-	GnomeCanvasItem *generateItem(int x, int y, int color);
-
-	const Block * const getFieldAt(int x, int y) {return &(field[x][y]);}
 
 private:
 	bool blockOkHere(int x, int y, int b, int r);
+	void eliminateLine(int l);
+
+protected:
 	Block **field;
-	bool field_initialized;
-	Field *fieldDisplay;
+
+	int blocknr;
+	int rot;
+	int color;
+
+	int posx;
+	int posy;
 };
 
 #endif //__blockops_h__
