@@ -1,6 +1,5 @@
 /* -*- mode:C++; tab-width:8; c-basic-offset:8; indent-tabs-mode:true -*- */
 
-
 /*
  * written by J. Marcin Gorycki <marcin.gorycki@intel.com>
  *
@@ -29,6 +28,7 @@
 #include "scoreframe.h"
 #include "sound.h"
 #include "highscores.h"
+#include "renderer.h"
 
 #include <games-gconf.h>
 #include <games-frame.h>
@@ -42,20 +42,11 @@
 #include <dirent.h>
 #include <string.h>
 
-GdkPixbuf **pic;
-
 int LINES = 20;
 int COLUMNS = 11;
 
 int BLOCK_SIZE = 40;
 
-int posx = COLUMNS / 2;
-int posy = 0;
-
-int blocknr = 0;
-int rot = 0;
-int color = 0;
-
 int blocknr_next = -1;
 int rot_next = -1;
 int color_next = -1;
@@ -66,26 +57,33 @@ bool rotateCounterClockWise = true;
 
 #define TETRIS_OBJECT "gnometris-tetris-object"
 
-#define KEY_OPTIONS_DIR "/apps/gnometris/options"
-#define KEY_SOUND "/apps/gnometris/options/sound"
-#define KEY_BLOCK_PIXMAP "/apps/gnometris/options/block_pixmap"
-#define KEY_STARTING_LEVEL "/apps/gnometris/options/starting_level"
-#define KEY_DO_PREVIEW "/apps/gnometris/options/do_preview"
-#define KEY_RANDOM_BLOCK_COLORS "/apps/gnometris/options/random_block_colors"
-#define KEY_ROTATE_COUNTER_CLOCKWISE "/apps/gnometris/options/rotate_counter_clock_wise"
-#define KEY_LINE_FILL_HEIGHT "/apps/gnometris/options/line_fill_height"
-#define KEY_LINE_FILL_PROBABILITY "/apps/gnometris/options/line_fill_probability"
+#define KEY_BASE "/apps/gnometris"
 
-#define KEY_CONTROLS_DIR "/apps/gnometris/controls"
-#define KEY_MOVE_LEFT "/apps/gnometris/controls/key_left"
-#define KEY_MOVE_RIGHT "/apps/gnometris/controls/key_right"
-#define KEY_MOVE_DOWN "/apps/gnometris/controls/key_down"
-#define KEY_MOVE_DROP "/apps/gnometris/controls/key_drop"
-#define KEY_MOVE_ROTATE "/apps/gnometris/controls/key_rotate"
-#define KEY_MOVE_PAUSE "/apps/gnometris/controls/key_pause"
+#define KEY_OPTIONS_DIR KEY_BASE "/options"
 
-#define KEY_BG_COLOUR "/apps/gnometris/options/bgcolor"
-#define KEY_USE_BG_IMAGE "/apps/gnometris/options/usebgimage"
+#define KEY_SOUND KEY_OPTIONS_DIR "/sound"
+#define KEY_BLOCK_PIXMAP KEY_OPTIONS_DIR "/block_pixmap"
+#define KEY_THEME KEY_OPTIONS_DIR "/theme"
+#define KEY_STARTING_LEVEL KEY_OPTIONS_DIR "/starting_level"
+#define KEY_DO_PREVIEW KEY_OPTIONS_DIR "/do_preview"
+#define KEY_RANDOM_BLOCK_COLORS KEY_OPTIONS_DIR "/random_block_colors"
+#define KEY_ROTATE_COUNTER_CLOCKWISE KEY_OPTIONS_DIR "/rotate_counter_clock_wise"
+#define KEY_LINE_FILL_HEIGHT KEY_OPTIONS_DIR "/line_fill_height"
+#define KEY_LINE_FILL_PROBABILITY KEY_OPTIONS_DIR "/line_fill_probability"
+
+#define KEY_CONTROLS_DIR KEY_BASE "/controls"
+#define KEY_MOVE_LEFT KEY_CONTROLS_DIR "/key_left"
+#define KEY_MOVE_RIGHT KEY_CONTROLS_DIR "/key_right"
+#define KEY_MOVE_DOWN KEY_CONTROLS_DIR "/key_down"
+#define KEY_MOVE_DROP KEY_CONTROLS_DIR "/key_drop"
+#define KEY_MOVE_ROTATE KEY_CONTROLS_DIR "/key_rotate"
+#define KEY_MOVE_PAUSE KEY_CONTROLS_DIR "/key_pause"
+
+#define KEY_BG_COLOUR KEY_OPTIONS_DIR "/bgcolor"
+#define KEY_USE_BG_IMAGE KEY_OPTIONS_DIR "/usebgimage"
+
+#define KEY_HEIGHT KEY_OPTIONS_DIR "/height"
+#define KEY_WIDTH KEY_OPTIONS_DIR "/width"
 
 #define TILE_THRESHOLD 65
 
@@ -98,13 +96,12 @@ enum {
 
 
 Tetris::Tetris(int cmdlLevel): 
-	blockPixmap(0),
+	themeno (0),
 	field(0),
 	paused(false), 
 	timeoutId(0), 
 	onePause(false), 
 	inPlay(false),
-	image(0),
 	bgimage(0),
 	setupdialog(0), 
 	cmdlineLevel(cmdlLevel), 
@@ -115,7 +112,9 @@ Tetris::Tetris(int cmdlLevel):
 	GtkAccelGroup *accel_group;
 	GtkActionGroup *action_group;
 	GtkWidget *vbox;
+	GtkWidget *aspect_frame;
 	GtkWidget *menubar;
+	gint width, height;
 
 	gchar *outdir;
 	const GtkTargetEntry targets[] = {{"text/uri-list", 0, URI_LIST}, 
@@ -166,10 +165,6 @@ Tetris::Tetris(int cmdlLevel):
 	if (!sound)
 		sound = new Sound();
 
-	pic = new GdkPixbuf*[tableSize];
-	for (int i = 0; i < tableSize; ++i)
-		pic[i] = 0;
-
 	/* Locate our background image. */
 	outdir = g_build_filename (gnome_user_dir_get (), "gnometris.d", 
 				   NULL);
@@ -180,7 +175,6 @@ Tetris::Tetris(int cmdlLevel):
 	
 	w = gnome_app_new("gnometris", _("Gnometris"));
 	g_signal_connect (w, "delete_event", G_CALLBACK (gameQuit), this);
-	gtk_window_set_resizable (GTK_WINDOW (w), FALSE);
 	gtk_drag_dest_set (w, GTK_DEST_DEFAULT_ALL, targets, 
 			   G_N_ELEMENTS(targets), 
 			   GDK_ACTION_MOVE);
@@ -188,13 +182,14 @@ Tetris::Tetris(int cmdlLevel):
 			  G_CALLBACK (dragDrop), this);
 	g_signal_connect (G_OBJECT (w), "focus_out_event",
 			  G_CALLBACK (focusOut), this);
+	g_signal_connect (G_OBJECT (w), "configure_event",
+			  G_CALLBACK (configure), this);
 
 	line_fill_height = 0;
 	line_fill_prob = 5;
 
 	/* init gconf */
 	gconf_client = gconf_client_get_default ();
-	games_gconf_sanity_check_string (gconf_client, KEY_BLOCK_PIXMAP);
 
 	gconf_client_add_dir (gconf_client, KEY_OPTIONS_DIR, GCONF_CLIENT_PRELOAD_NONE, NULL);
 	gconf_client_notify_add (gconf_client, KEY_OPTIONS_DIR, gconfNotify, this, NULL, NULL);
@@ -202,7 +197,18 @@ Tetris::Tetris(int cmdlLevel):
 	gconf_client_add_dir (gconf_client, KEY_CONTROLS_DIR, GCONF_CLIENT_PRELOAD_NONE, NULL);
 	gconf_client_notify_add (gconf_client, KEY_CONTROLS_DIR, gconfNotify, this, NULL, NULL);
 
-	preview = new Preview();
+
+	width = gconf_client_get_int (gconf_client, KEY_WIDTH, NULL);
+	if (width <= 0)
+		width = 440;
+	height = gconf_client_get_int (gconf_client, KEY_HEIGHT, NULL);
+	if (height <= 0)
+		height = 550;
+
+	gtk_window_set_default_size (GTK_WINDOW (w), width, height);
+
+	preview = new Preview ();
+	field = new Field();
 
 	initOptions ();
 
@@ -235,17 +241,18 @@ Tetris::Tetris(int cmdlLevel):
 	gtk_box_pack_start (GTK_BOX (vbox), menubar, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox), hb, TRUE, TRUE, 0);
 
-	field = new Field();
-	ops = new BlockOps(field);
+	aspect_frame = gtk_aspect_frame_new (NULL, 0.5, 0.5, (float) COLUMNS / (float) LINES, FALSE);
+	gtk_frame_set_shadow_type (GTK_FRAME (aspect_frame), GTK_SHADOW_NONE);
+	gtk_container_add (GTK_CONTAINER (aspect_frame), field->getWidget());
 
 	gtk_widget_set_events(w, gtk_widget_get_events(w) | 
 						  GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK);
-	
+
 	GtkWidget *vb1 = gtk_vbox_new(FALSE, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(vb1), 10);
-	gtk_box_pack_start_defaults(GTK_BOX(vb1), field->getWidget());
-	gtk_box_pack_start(GTK_BOX(hb), vb1, 0, 0, 0);
-	gtk_widget_show(field->getWidget());
+	gtk_box_pack_start_defaults(GTK_BOX(vb1), aspect_frame);
+	gtk_box_pack_start_defaults(GTK_BOX(hb), vb1);
+
 	setupPixmap();
 
 	g_signal_connect (w, "key_press_event", G_CALLBACK (keyPressHandler), this);
@@ -260,6 +267,7 @@ Tetris::Tetris(int cmdlLevel):
 	scoreFrame = new ScoreFrame(cmdlineLevel);
 	
 	gtk_box_pack_end(GTK_BOX(vb2), scoreFrame->getWidget(), TRUE, FALSE, 0);
+	high_scores = new HighScores ();
 
 	setOptions ();
 	setupScoreState ();
@@ -269,52 +277,36 @@ Tetris::Tetris(int cmdlLevel):
 	gtk_widget_show(hb);
 	gtk_widget_show(vb1);
 	gtk_widget_show(vb2);
+	gtk_widget_show(aspect_frame);
+	gtk_widget_show(field->getWidget());
 	scoreFrame->show();
 	gtk_widget_show(w);
 
 	gtk_action_set_sensitive(pause_action, FALSE);
 	gtk_action_set_sensitive(end_game_action, FALSE);
 	gtk_action_set_sensitive(preferences_action, TRUE);
-
-	high_scores = new HighScores ();
 }
 
 Tetris::~Tetris()
 {
-	delete ops;
 	delete field;
 	delete preview;
 	delete scoreFrame;
 
-	if (image)
-		g_object_unref (G_OBJECT (image));
 	if (bgimage)
 		g_object_unref (G_OBJECT (bgimage));		
 
-	if (blockPixmap)
-		g_free(blockPixmap);
 	if (bgPixmap)
 		g_free(bgPixmap);
-
-	delete[] pic;
 }
 
 void
 Tetris::setupScoreState ()
 {
-        gchar **names = NULL;
-        gfloat *scores = NULL;
-        time_t *scoretimes = NULL;
-	gint top = 0;
-
-	top = gnome_score_get_notable ("gnometris", NULL, &names, &scores, &scoretimes);
-	if (top > 0) {
-		gtk_action_set_sensitive (scores_action, TRUE);
-		g_strfreev (names);
-		g_free (scores);
-		g_free (scoretimes);
-	} else {
+	if (high_scores->empty ()) {
 		gtk_action_set_sensitive (scores_action, FALSE);
+	} else {
+		gtk_action_set_sensitive (scores_action, TRUE);
 	}
 }
 
@@ -339,60 +331,6 @@ Tetris::setupdialogResponse (GtkWidget *dialog, gint response_id, void *d)
 void
 Tetris::setupPixmap()
 {
-	gchar *pixname, *fullpixname;
-	
-	pixname = g_build_filename ("gnometris", blockPixmap, NULL);
-	fullpixname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP, pixname, FALSE, NULL);
-	g_free (pixname);
-
-	if (!g_file_test (fullpixname, G_FILE_TEST_EXISTS))
-	{
-		g_free (fullpixname);
-		fullpixname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP, "gnometris/7blocks-gw.png", FALSE, NULL);
-	}
-	
-	if (!g_file_test (fullpixname, G_FILE_TEST_EXISTS))
-	{
-		GtkWidget *widget = gtk_message_dialog_new (NULL,
-						       GTK_DIALOG_DESTROY_WITH_PARENT,
-						       GTK_MESSAGE_ERROR,
-						       GTK_BUTTONS_OK,
-						       _("Could not find the theme: \n%s\n\nPlease check your gnome-games installation"), fullpixname);
-		gtk_dialog_run (GTK_DIALOG (widget));
-		exit(1);
-	}
-
-	if(image)
-		g_object_unref (G_OBJECT (image));
-
-	image = gdk_pixbuf_new_from_file(fullpixname, NULL);
-
-	if (image == NULL) {
-		GtkWidget *widget= gtk_message_dialog_new (NULL,
-						       GTK_DIALOG_DESTROY_WITH_PARENT,
-						       GTK_MESSAGE_ERROR,
-						       GTK_BUTTONS_OK,
-						       _("Can't load the image: \n%s\n\nPlease check your gnome-games installation"), fullpixname);
-		gtk_dialog_run (GTK_DIALOG (widget));
-		exit (1);
-	}
-	g_free (fullpixname);
-
-	BLOCK_SIZE = gdk_pixbuf_get_height(image);
-	nr_of_colors = gdk_pixbuf_get_width(image) / BLOCK_SIZE;
-
-	for (int i = 0; i < tableSize; ++i)
-	{
-		if (pic[i])
-			g_object_unref (G_OBJECT (pic[i]));
-
-		pic[i] = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, BLOCK_SIZE, BLOCK_SIZE);
-
-		gdk_pixbuf_copy_area (image, (i % nr_of_colors) * BLOCK_SIZE, 0,
-					BLOCK_SIZE, BLOCK_SIZE, pic[i], 0, 0);
-
-	}
-
 	if (bgimage)
 		g_object_unref (G_OBJECT (bgimage));
 
@@ -450,14 +388,16 @@ Tetris::setupPixmap()
 
 	if (field)
 	{
-		field->updateSize (bgimage, &bgcolour);
-		gtk_widget_queue_resize (field->getWidget());
+		if (bgimage)
+			field->setBackground (bgimage);
+		else
+			field->setBackground (&bgcolour);
 	}
 	
 	if (preview)
 	{
-		preview->updateSize ();
-		gtk_widget_queue_resize (field->getWidget());
+		/* FIXME: We should do an update once the preview actually
+		 * uses the background pixbuf. */
 	}
 }
 
@@ -526,10 +466,9 @@ Tetris::initOptions ()
 {
 	gchar *bgcolourstr;
 
-	if (blockPixmap)
-		g_free (blockPixmap);
-
-	blockPixmap = gconfGetString (gconf_client, KEY_BLOCK_PIXMAP, "7blocks-tig.png");
+	themeno = themeNameToNumber (gconfGetString (gconf_client, KEY_THEME, "plain"));
+	field->setTheme (themeno);
+	preview->setTheme (themeno);
 
 	startingLevel = gconfGetInt (gconf_client, KEY_STARTING_LEVEL, 1);
 	if (startingLevel < 1) 
@@ -543,8 +482,10 @@ Tetris::initOptions ()
 		sound->turnOff ();
 
 	do_preview = gconfGetBoolean (gconf_client, KEY_DO_PREVIEW, TRUE);
-	if (preview)
+	
+	if (preview) {
 		preview->enable(do_preview);
+	}
 
 	random_block_colors = gconfGetBoolean (gconf_client, KEY_RANDOM_BLOCK_COLORS, TRUE);
 
@@ -588,8 +529,10 @@ Tetris::setOptions ()
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (random_block_colors_toggle), random_block_colors);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (rotate_counter_clock_wise_toggle), rotateCounterClockWise);
 
-		if (theme_preview)
+		if (theme_preview) {
+			theme_preview->setTheme (themeno);
 			gtk_widget_queue_draw(theme_preview->getWidget());
+		}
 	}
 
 	scoreFrame->setLevel (startingLevel);
@@ -635,13 +578,12 @@ Tetris::setSelection(GtkWidget *widget, void *data)
 	Tetris *t;
 	GList * item;
 
-      	t = (Tetris *)g_object_get_data (G_OBJECT (widget), TETRIS_OBJECT);
+      	t = (Tetris *)data;
 
-	item = g_list_nth (t->themeList,
-			   gtk_combo_box_get_active (GTK_COMBO_BOX (widget)));
-
-	gconf_client_set_string (t->gconf_client, KEY_BLOCK_PIXMAP,
-				 (char *)item->data, NULL);
+	t->themeno = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
+	t->field->setTheme (t->themeno);
+	gconf_client_set_string (t->gconf_client, KEY_THEME,
+				 ThemeTable[t->themeno].id, NULL);
 }
 
 void
@@ -921,19 +863,24 @@ Tetris::gameProperties(GtkAction *action, void *d)
 	label = gtk_label_new (_("Theme"));
 	gtk_notebook_append_page (GTK_NOTEBOOK(notebook), vbox, label);
 
-	frame = games_frame_new (_("Block image:"));
+	frame = games_frame_new (_("Block Style"));
 	gtk_container_add (GTK_CONTAINER (vbox), frame);
 
 	fvbox = gtk_vbox_new (FALSE, 6);
 	gtk_container_add (GTK_CONTAINER (frame), fvbox);
 
 	GtkWidget *omenu = gtk_combo_box_new_text ();
-	g_object_set_data (G_OBJECT (omenu), TETRIS_OBJECT, t);	
-	t->fillMenu (omenu, t->blockPixmap, "gnometris", &(t->themeList));
-	g_signal_connect (omenu, "changed", G_CALLBACK (setSelection), NULL);
+	ThemeTableEntry *entry = ThemeTable;
+	while (entry->id) {
+		gtk_combo_box_append_text (GTK_COMBO_BOX (omenu), entry->name);
+		entry++;
+	}
+	gtk_combo_box_set_active (GTK_COMBO_BOX (omenu), t->themeno);
+	g_signal_connect (omenu, "changed", G_CALLBACK (setSelection), t);
 	gtk_box_pack_start (GTK_BOX (fvbox), omenu, FALSE, FALSE, 0);
 
 	t->theme_preview = new Preview();
+	t->theme_preview->setTheme (t->themeno);
 	gtk_box_pack_start(GTK_BOX(fvbox), t->theme_preview->getWidget(), TRUE, TRUE, 0);
 
 	t->theme_preview->previewBlock(4, 0, 0);
@@ -979,7 +926,7 @@ Tetris::gameQuit(GtkAction *action, void *d)
 
 	/* Record the score if the game isn't over. */
 	if (t->inPlay && (t->scoreFrame->getScore() > 0))
-		gnome_score_log(t->scoreFrame->getScore(), 0, TRUE);
+		t->high_scores->add (t->scoreFrame->getScore());
 
 	if (t->w)
 		gtk_widget_destroy(t->w);
@@ -1003,12 +950,12 @@ Tetris::generateTimer(int level)
 void
 Tetris::manageFallen()
 {
-	ops->fallingToLaying();
+	field->fallingToLaying();
 	sound->playSound (SOUND_LAND);
 
 	int levelBefore = scoreFrame->getLevel();
 
-	int fullLines = ops->checkFullLines();
+	int fullLines = field->checkFullLines();
 	if (fullLines > 0)
 		scoreFrame->incLines(fullLines);
 	int levelAfter = scoreFrame->getLevel();
@@ -1031,12 +978,13 @@ Tetris::timeoutHandler(void *d)
  	if (t->onePause)
  	{
 		t->onePause = false;
-		gtk_widget_queue_draw(t->field->getWidget());
+		t->field->redraw();
 	}
  	else
 	{
-		bool res = t->ops->moveBlockDown();
-		gtk_widget_queue_draw(t->field->getWidget());
+		bool res = t->field->moveBlockDown();
+
+		t->field->redraw();
 
 		if (res)
 		{
@@ -1075,17 +1023,17 @@ Tetris::keyPressHandler(GtkWidget *widget, GdkEvent *event, Tetris *t)
 		return FALSE;
 
 	if (keyval == t->moveLeft) {
-		res = t->ops->moveBlockLeft();
+		res = t->field->moveBlockLeft();
 		if (res)
 			sound->playSound (SOUND_SLIDE);
 		t->onePause = false;
 	} else if (keyval == t->moveRight) {
-		res = t->ops->moveBlockRight();
+		res = t->field->moveBlockRight();
 		if (res)
 			sound->playSound (SOUND_SLIDE);
 		t->onePause = false;
 	} else if (keyval == t->moveRotate) {
-		res = t->ops->rotateBlock(rotateCounterClockWise);
+		res = t->field->rotateBlock(rotateCounterClockWise);
 		if (res)
 			sound->playSound (SOUND_TURN);
 		t->onePause = false;
@@ -1100,13 +1048,15 @@ Tetris::keyPressHandler(GtkWidget *widget, GdkEvent *event, Tetris *t)
 	} else if (keyval == t->moveDrop) {
 		if (!t->dropBlock) {
 			t->dropBlock = true;
-			bonus = t->ops->dropBlock();
+			bonus = t->field->dropBlock();
 			t->scoreFrame->incScore(bonus);
 			t->manageFallen();
 			res = TRUE;
 		}        
 	}
 
+	t->field->redraw();
+
 	return res;
 }
 
@@ -1330,7 +1280,6 @@ Tetris::dragDrop(GtkWidget *widget, GdkDragContext *context,
 	gnome_vfs_close (inhandle);
  error_exit:
 	return;
-
 }
 
 void
@@ -1352,9 +1301,9 @@ Tetris::togglePause()
 void
 Tetris::generate()
 {
-	if (ops->generateFallingBlock())
+	if (field->generateFallingBlock())
 	{
-		ops->putBlockInField(false);
+		field->putBlockInField(false);
 		preview->previewBlock(blocknr_next, rot_next, color_next);
 		gtk_widget_queue_draw(preview->getWidget());
 		onePause = true;
@@ -1389,7 +1338,7 @@ Tetris::endOfGame()
 
 	if (scoreFrame->getScore() > 0) 
 	{
-		int pos = gnome_score_log(scoreFrame->getScore(), 0, TRUE);
+		int pos = high_scores->add (scoreFrame->getScore());
 		high_scores->show (pos);
 	}
 }
@@ -1407,7 +1356,7 @@ Tetris::gameNew(GtkAction *action, void *d)
 		/* Catch the case where we started a new game without
 		 * finishing the old one. */
 		if ((t->scoreFrame->getScore() > 0) && t->inPlay)
-			gnome_score_log(t->scoreFrame->getScore(), 0, TRUE);
+			t->high_scores->add (t->scoreFrame->getScore());
 	}
 
 	t->inPlay = true;
@@ -1420,13 +1369,14 @@ Tetris::gameNew(GtkAction *action, void *d)
 	t->scoreFrame->setStartingLevel(level);
 
 	t->timeoutId = g_timeout_add_full(0, 1000 - 100 * (level - 1), timeoutHandler, t, NULL);
-	t->ops->emptyField(t->line_fill_height,t->line_fill_prob);
+	t->field->emptyField(t->line_fill_height,t->line_fill_prob);
 
 	t->scoreFrame->resetLines();
 	t->paused = false;
 	
-	t->ops->generateFallingBlock();
-	gtk_widget_queue_draw(t->field->getWidget());
+	t->field->generateFallingBlock();
+	//gtk_widget_queue_draw(t->field->getWidget());
+	t->field->redraw();
 	t->preview->previewBlock(blocknr_next, rot_next, color_next);
 	gtk_widget_queue_draw(t->preview->getWidget());
 
@@ -1457,7 +1407,7 @@ Tetris::gameAbout(GtkAction *action, void *d)
 {
 	Tetris *t = (Tetris*) d;
 
-	const gchar *authors[] = { "J. Marcin Gorycki", NULL };
+	const gchar * const authors[] = { "J. Marcin Gorycki", NULL };
 
 	gtk_show_about_dialog (GTK_WINDOW (t->getWidget()),
 			       "name", _("Gnometris"),
@@ -1481,3 +1431,13 @@ Tetris::gameTopTen(GtkAction *action, void *d)
 
 	return TRUE;
 }
+
+gboolean Tetris::configure (GtkWidget *widget, GdkEventConfigure *event, Tetris *t)
+{
+
+	gconf_client_set_int (t->gconf_client, KEY_WIDTH, event->width, NULL);
+	gconf_client_set_int (t->gconf_client, KEY_HEIGHT, event->height, 
+			      NULL);
+
+	return FALSE;
+}
